@@ -17,30 +17,29 @@ from ._markup_annotations import (
     FreeText,
     Highlight,
     Line,
-    Link,
     MarkupAnnotation,
     Polygon,
     PolyLine,
     Rectangle,
     Text,
 )
-from ._non_markup_annotations import Popup
+from ._non_markup_annotations import Link, Popup
 
 __all__ = [
     "NO_FLAGS",
     # Export abstract base classes so that they are shown in the docs
     "AnnotationDictionary",
     "MarkupAnnotation",
-    # markup annotations
+    # Markup annotations
     "Ellipse",
     "FreeText",
     "Highlight",
     "Line",
-    "Link",
     "Polygon",
     "PolyLine",
     "Rectangle",
     "Text",
     # Non-markup annotations
+    "Link",
     "Popup",
 ]
